@@ -1,5 +1,5 @@
 package Mojolicious::Plugin::JSONAPI;
-$Mojolicious::Plugin::JSONAPI::VERSION = '0.9';
+$Mojolicious::Plugin::JSONAPI::VERSION = '1.0';
 use Mojo::Base 'Mojolicious::Plugin';
 
 use JSONAPI::Document;
@@ -57,7 +57,7 @@ sub create_route_helpers {
 
             my $base_path = (!$spec->{router} && $namespace) ? "/$namespace/$resource_plural" : "/$resource_plural";
             my $router = $spec->{router} ? $spec->{router} : $app->routes;
-            my $controller = $spec->{controller} || "api-$resource_plural";
+            my $controller = $spec->{controller} || "api-$action_plural";
 
             my $r = $router->any($base_path)->to( controller => $controller );
             $r->get('/')->to( action => "fetch_${action_plural}" );
@@ -178,7 +178,7 @@ Mojolicious::Plugin::JSONAPI - Mojolicious Plugin for building JSON API complian
 
 =head1 VERSION
 
-version 0.9
+version 1.0
 
 =head1 SYNOPSIS
 
